=========================
Oscar 1.1.1 release notes
=========================

:release: 2015-08-05

This is Oscar 1.1.1, a bug fix release.

Bug fixes
=========

* `#1802`_: The glyphicons fonts were missing from the release. This could cause Django's
  ``collectstatic`` command to fail.

  .. _#1802: https://github.com/django-oscar/django-oscar/issues/1802
